#' wbstats: An R package for searching and downloading data from the World Bank API.
#'
#' The wbstats package provides structured access to data
#' available from the World Bank API including; support for mutliple languages,
#' access to annual, quarterly, and monthly data.
#'
#' @importFrom tibble tibble
#' @name wbstats
"_PACKAGE"
